@@ -1,7 +1,7 @@
 from typing import Tuple, Optional, Dict
 
-from tensorflow.keras.models import Model
-from tensorflow.keras.layers import Layer
+from keras.models import Model
+from keras.layers import Layer
 
 from leap_model_rebuilder.modelexpander import expand_model
 from leap_model_rebuilder.utils import is_custom_layers, convert_subclassed_to_functional, should_replace_layers, \
