@@ -2,9 +2,9 @@ import logging
 from typing import Tuple, Dict
 
 import tensorflow as tf
-from tensorflow.keras import Model, Input
-from tensorflow.keras.layers import Layer
-from tensorflow.python.keras.models import Functional  # pylint: disable=no-name-in-module
+from keras import Model, Input
+from keras.layers import Layer
+from keras.models import Functional
 
 
 def is_custom_layers(model: Model) -> bool:
